============
Installation
============

In order to use ACT, you must have Python 3.6+ installed.

You can build the Atmospheric data Community Toolkit from source and install it doing::


    $ git clone https://github.com/ARM-DOE/ACT
    $ cd ACT
    $ python setup.py install

ACT is also available on Anaconda and PyPI. To install from PyPI:

    $ pip install act-atmos

To install from Anaconda conda-forge::

    $ conda install -c conda-forge act-atmos
